Task: Deal or No Deal
======================
Description: End-to-end negotiation task which requires two agents to agree on how to divide a set of items, with each agent assigning different values to each item. From Lewis et al. '17. 

Link: https://arxiv.org/abs/1706.05125

Tags: #DealNoDeal, #All, #Negotiation

